.. PuReX documentation master file, created by
   sphinx-quickstart on Sat Jul  5 23:39:58 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

PuReX documentation
===================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

